import { ExtractPropTypes, PropType, Ref } from "vue";
import { AxiosRequestConfig } from "axios";
export interface ActionConfig {
    editText?: string;
    deleteText?: string;
    showEdit?: boolean;
    showDelete?: boolean;
    editRowEnterText?: string;
    editRowCloseText?: string;
    custom?: (list: {
        [prop: string]: any;
    }[], scope: any) => {
        [prop: string]: any;
    }[];
}
export declare type TableOptions = {
    [prop: string | number | symbol]: any;
    slot?: string;
    action?: boolean;
    actionConfig?: ActionConfig;
    editable?: boolean;
    editableConfig?: {
        showEnter?: boolean;
        showClose?: boolean;
        custom?: (list: {
            [prop: string]: any;
        }[], scope: any, isEdit: Ref<boolean>) => {
            [prop: string]: any;
        }[];
    };
    type?: "selection" | "index" | "expand";
    index?: number | ((index: number) => void);
    label?: string | Ref<any>;
    columnKey?: string;
    prop?: string;
    width?: string | number;
    minWidth?: string | number;
    fixed?: true | "left" | "right";
    renderHeader?(data: {
        column: any;
        $index: number;
    }): void;
    sortable?: true | false | "custom";
    sortMethod?(a: number, b: number): number;
    sortBy?: (row: any, index: number) => void | string | any[];
    sortOrders?: any[];
    resizable?: boolean;
    formatter?(row: any, column: any, cellValue: any, index: number): void;
    showOverflowTooltip?: boolean;
    align?: "left" | "center" | "right";
    headerAlign?: "left" | "center" | "right";
    className?: string;
    labelClassName?: string;
    selectable?(row: any, index: number): boolean;
    reserveSelection?: boolean;
    filters?: {
        text: any;
        value: any;
    }[];
    filterPlacement?: "top" | "top-start" | "top-end" | "bottom" | "bottom-start" | "bottom-end" | "left" | "left-start" | "left-end" | "right" | "right-start" | "right-end";
    filterMultiple?: boolean;
    filterMethod?(value: any, row: any, column: any): void;
    filteredValue?: any[];
};
export declare const tableProps: {
    readonly options: PropType<TableOptions[]>;
    readonly editRow: BooleanConstructor;
    readonly showPagination: {
        readonly type: BooleanConstructor;
    };
    readonly server: {
        readonly type: PropType<(...rest: any[]) => Promise<any>>;
        readonly default: import("axios").AxiosStatic;
    };
    readonly getUrl: StringConstructor;
    readonly withDataPath: {
        readonly type: PropType<string | boolean>;
        readonly default: null;
    };
    readonly withPagePath: {
        readonly type: PropType<string | boolean>;
        readonly default: null;
    };
    readonly withQuery: ObjectConstructor;
    readonly withQueryPath: {
        readonly type: PropType<string | boolean>;
        readonly default: null;
    };
    readonly stringify: BooleanConstructor;
    readonly getConfig: {
        readonly type: PropType<AxiosRequestConfig<any>>;
        readonly default: () => {
            method: string;
        };
    };
    readonly replaceFields: {
        readonly type: PropType<{
            pageSize?: string | undefined;
            currentPage?: string | undefined;
        }>;
        readonly default: () => {
            pageSize: string;
            currentPage: string;
        };
    };
    readonly dataPath: {
        readonly type: StringConstructor;
        readonly default: "data.data";
    };
    readonly totalPath: {
        readonly type: StringConstructor;
        readonly default: "data.total";
    };
    readonly showLoadInGet: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly elementLoadingText: {
        readonly type: StringConstructor;
        readonly default: "正在加载中...";
    };
    readonly elLoadingTextTimeout: {
        readonly type: NumberConstructor;
        readonly default: 8000;
    };
    readonly elLoadingTextTimeoutText: {
        readonly type: StringConstructor;
        readonly default: "数据加载较慢，请耐心等待...";
    };
    readonly emptyTip: {
        readonly type: StringConstructor;
        readonly default: "正在加载中...";
    };
    readonly emptyTipTimeout: {
        readonly type: NumberConstructor;
        readonly default: 8000;
    };
    readonly emptyTipTimeoutText: {
        readonly type: StringConstructor;
        readonly default: "数据加载较慢，请耐心等待...";
    };
    readonly defaultCurrentPage: NumberConstructor;
    readonly defaultPageSize: NumberConstructor;
    readonly actionConfig: {
        readonly type: PropType<ActionConfig>;
        readonly default: () => {};
    };
};
export declare type TableProps = ExtractPropTypes<typeof tableProps>;
export declare const tableEmits: {
    edit: null;
    delete: null;
    confirmEditRow: null;
    cancelEditRow: null;
    confirmEditCell: null;
    cancelEditCell: null;
    beforeGetData: (val: any) => boolean;
    afterGetData: (val: any) => boolean;
    failToGetData: (val: any) => boolean;
};
export declare type TableEmits = ExtractPropTypes<typeof tableEmits>;
